[Zodb-checkins] CVS: ZODB3/zdaemon - zdctl.sh:1.2

Guido van Rossum guido@python.org
Tue, 26 Nov 2002 13:11:21 -0500


Update of /cvs-repository/ZODB3/zdaemon
In directory cvs.zope.org:/tmp/cvs-serv29265

Modified Files:
	zdctl.sh 
Log Message:
Use more conventional envvar names.


=== ZODB3/zdaemon/zdctl.sh 1.1 => 1.2 ===
--- ZODB3/zdaemon/zdctl.sh:1.1	Tue Nov 26 12:39:22 2002
+++ ZODB3/zdaemon/zdctl.sh	Tue Nov 26 13:11:20 2002
@@ -5,23 +5,23 @@
 #
 # chkconfig: 345 90 10
 # description: start a Zope-related server (Zope, ZEO or ZRS)
-#
-# (XXX If there are more conventional names for some of the envvars
-# below, please check in a fix.  INSTANCE_HOME, ZOPE_HOME and
-# SOFTWARE_HOME still confuse me.)
 
 # Edit to indicate which Python to use
 PYTHON=/usr/local/bin/python2.2
 
-# Edit to indicate where your Zope modules are
-ZOPELIB=$HOME/projects/ZODB3
+# Edit to indicate where the core Zope software lives
+ZOPE_HOME=$HOME/projects/Zope
 
-# Edit to indicate where your config file is (may be a URL too)
-CONFIGFILE=$ZOPELIB/zdaemon/sample.conf
+# Edit to indicate where your Zope instance lives
+INSTANCE_HOME=$HOME/projects/Zope
+
+# Edit to indicate where your config file is
+CONFIG_LOCATION=$INSTANCE_HOME/sample.conf
 
 # You shouldn't need to edit these
-ZDCTL=$ZOPELIB/zdaemon/zdctl.py
-CMD="$PYTHON $ZDCTL -C $CONFIGFILE"
+SOFTWARE_HOME=$ZOPE_HOME/lib/python
+ZDCTL=$SOFTWARE_HOME/zdaemon/zdctl.py
+CMD="$PYTHON $ZDCTL -C $CONFIG_LOCATION"
 
 # Parse the command line
 case $1 in